Enum rexsgdata::Element[][src]

pub enum Element {
    Zle(usize),
    Iovec(iovec),
}

Intermediate element that can represent either regular iovec or a sequence of zeroes

Variants

A block of zeroes of a specified size (aka Zero Length Encoding)

Regular iovec

Methods

impl Element
[src]

Constructs Element::Zle variant of a specified size