Enum rexsgdata::SgData [−][src]
High Level wrapper for multiple data representation methods.
Variants
SgList(SgList)Classic Scatter Gather list as it comes from C (array of iovec elements)
SgVec(Vec<Vec<u8>>)Vec
Direct(Vec<u8>)Plain Vec
Element(Vec<Element>)Special case for iovec array that is itself a Rust' Vec
Methods
impl SgData[src]
impl SgDatapub fn iter(
&self
) -> impl Iterator<Item = &[u8]>[src]
pub fn iter(
&self
) -> impl Iterator<Item = &[u8]>Iterates over all the underlying byte slices of this SgData.
pub fn len(&self) -> usize[src]
pub fn len(&self) -> usizeReturns number of elements in the underlying object, NOT the total number of bytes.
pub fn is_empty(&self) -> bool[src]
pub fn is_empty(&self) -> boolChecks this SgData for containing any byte slice
pub unsafe fn clone_into(self, iovec: *mut iovec, count: c_int) -> Self[src]
pub unsafe fn clone_into(self, iovec: *mut iovec, count: c_int) -> Self: use drain_into() instead
pub unsafe fn drain_into(self, iovec: *const iovec, count: usize) -> Self[src]
pub unsafe fn drain_into(self, iovec: *const iovec, count: usize) -> SelfMoves the data contained in this SgData instance into iovec.
Consumes this instance and creates a new one, based on the buffers
described by iovec and count.
pub unsafe fn clone_masked(&self, mask: Range<usize>) -> Self[src]
pub unsafe fn clone_masked(&self, mask: Range<usize>) -> SelfApplies the mask to the current object and creates a new SgData object which describes
only masked region
pub fn append(&mut self, other: &mut Self)[src]
pub fn append(&mut self, other: &mut Self): use Extend::extend() instead
pub fn is_element(&self) -> bool[src]
pub fn is_element(&self) -> boolChecks whether this instance is built from Element
pub fn is_sglist(&self) -> bool[src]
pub fn is_sglist(&self) -> boolChecks whether this instance is built from SgList
pub fn as_sglist(&self) -> &SgList[src]
pub fn as_sglist(&self) -> &SgListIf this object is built from SgList exposes the underlying SgList object.
pub fn to_sglist(&self) -> SgList[src]
pub fn to_sglist(&self) -> SgListIf this object is built from SgList clones the underlying SgList object.
pub fn zero(size: usize) -> Self[src]
pub fn zero(size: usize) -> SelfCreates an efficient (ZLE) zeroed buffer