Struct rexsgdata::SgList [−][src]
pub struct SgList { /* fields omitted */ }Expand description
Wrapper for a C-style scatter gather list
Implementations
impl SgList[src]
impl SgList[src]pub fn new(iovec: *const iovec, count: usize) -> Self[src]
pub fn new(iovec: *const iovec, count: usize) -> Self[src]Constructs new SgList object from raw arguments
pub fn into_inner(self) -> (*const iovec, usize)[src]
pub fn into_inner(self) -> (*const iovec, usize)[src]Deconstructs the SgList object into original building blocks.
pub unsafe fn index_ref_unchecked(&self, idx: isize) -> &iovec[src]
pub unsafe fn index_ref_unchecked(&self, idx: isize) -> &iovec[src]Returns a reference to a idx’ element of this Scatter Gather List
pub unsafe fn index_unchecked(&self, idx: isize) -> iovec[src]
pub unsafe fn iter(&self) -> impl Iterator<Item = &iovec>[src]
pub unsafe fn iter(&self) -> impl Iterator<Item = &iovec>[src]Iterates over &iovec stored in this SgList
pub unsafe fn into_iter(self) -> impl Iterator<Item = iovec>[src]
pub unsafe fn iter_static_slices(self) -> impl Iterator<Item = &'static [u8]>[src]
pub unsafe fn iter_slices_mut(&self) -> impl Iterator<Item = &mut [u8]>[src]
pub unsafe fn iter_slices_mut(&self) -> impl Iterator<Item = &mut [u8]>[src]Iterates over byte slices &u8
pub unsafe fn iter_range(&self) -> impl Iterator<Item = (&iovec, Range<usize>)>[src]
pub unsafe fn iter_range(&self) -> impl Iterator<Item = (&iovec, Range<usize>)>[src]Iterates over tuples of &iovec and associated Range describing this iovec position in
the whole SgList
pub unsafe fn iter_slices_range(
&self
) -> impl Iterator<Item = (&[u8], Range<usize>)>[src]
pub unsafe fn iter_slices_range(
&self
) -> impl Iterator<Item = (&[u8], Range<usize>)>[src]Iterates over tuples of &[u8] slices and associated Range describing this slice
position in the whole SgList
pub unsafe fn iter_slices_range_mut(
&self
) -> impl Iterator<Item = (&mut [u8], Range<usize>)>[src]
pub unsafe fn iter_slices_range_mut(
&self
) -> impl Iterator<Item = (&mut [u8], Range<usize>)>[src]Iterates over tuples of &mut [u8] slices and associated Range describing this slice
position in the whole SgList.
pub unsafe fn iter_masked(
&self,
mask: Range<usize>
) -> impl Iterator<Item = iovec> + '_[src]
pub unsafe fn iter_masked(
&self,
mask: Range<usize>
) -> impl Iterator<Item = iovec> + '_[src]Given a mask iterates over iovec that a visible after masking