[−][src]Struct rexsgdata::Zle
ZLE (Zero Length Encoding) is a compact representation of the sequence of zeros
Implementations
impl Zle[src]
pub fn new(capacity: usize) -> Self[src]
Constructs fresh Zle of a specified size
pub fn size(&self) -> usize[src]
Get the number of slices this Zle represents
pub fn is_empty(&self) -> bool[src]
pub fn iter_bytes(&self) -> impl Iterator<Item = u8>[src]
pub fn iter(&self) -> impl Iterator<Item = &[u8]>[src]
Get a view of an Element as an iterator of slices
Note Zle is represented by the same slice repeated