Struct rexsgdata::SgList [−][src]
pub struct SgList { /* fields omitted */ }Wrapper for a C-style scatter gather list
Methods
impl SgList[src]
impl SgListpub fn new(iovec: *const iovec, count: usize) -> Self[src]
pub fn new(iovec: *const iovec, count: usize) -> SelfConstructs new SgList object from raw arguments
pub fn into_inner(self) -> (*const iovec, usize)[src]
pub fn into_inner(self) -> (*const iovec, usize)Deconstructs the SgList object into original building blocks.
pub unsafe fn index_unchecked(&self, idx: isize) -> &iovec[src]
pub unsafe fn index_unchecked(&self, idx: isize) -> &iovecReturns a reference to a idx' element of this Scatter Gather List
pub unsafe fn iter(
&self
) -> impl Iterator<Item = &iovec>[src]
pub unsafe fn iter(
&self
) -> impl Iterator<Item = &iovec>Iterates over &iovec stored in this SgList
pub unsafe fn iter_slices(
&self
) -> impl Iterator<Item = &[u8]>[src]
pub unsafe fn iter_slices(
&self
) -> impl Iterator<Item = &[u8]>Iterates over byte slices &u8
pub unsafe fn iter_slices_mut(
&self
) -> impl Iterator<Item = &mut [u8]>[src]
pub unsafe fn iter_slices_mut(
&self
) -> impl Iterator<Item = &mut [u8]>Iterates over byte slices &u8
pub unsafe fn iter_range(
&self
) -> impl Iterator<Item = (&iovec, Range<usize>)>[src]
pub unsafe fn iter_range(
&self
) -> impl Iterator<Item = (&iovec, Range<usize>)>Iterates over tuples of &iovec and associated Range describing this iovec position in
the whole SgList
pub unsafe fn iter_slices_range(
&self
) -> impl Iterator<Item = (&[u8], Range<usize>)>[src]
pub unsafe fn iter_slices_range(
&self
) -> impl Iterator<Item = (&[u8], Range<usize>)>Iterates over tuples of &[u8] slices and associated Range describing this slice
position in the whole SgList
pub unsafe fn iter_slices_range_mut(
&self
) -> impl Iterator<Item = (&mut [u8], Range<usize>)>[src]
pub unsafe fn iter_slices_range_mut(
&self
) -> impl Iterator<Item = (&mut [u8], Range<usize>)>Iterates over tuples of &mut [u8] slices and associated Range describing this slice
position in the whole SgList.
pub unsafe fn iter_masked<'a>(
&'a self,
mask: Range<usize>
) -> impl Iterator<Item = iovec> + 'a[src]
pub unsafe fn iter_masked<'a>(
&'a self,
mask: Range<usize>
) -> impl Iterator<Item = iovec> + 'aGiven a mask iterates over iovec that a visible after masking