Struct rexsgdata::SgList[][src]

pub struct SgList { /* fields omitted */ }

Wrapper for a C-style scatter gather list

Methods

impl SgList
[src]

Constructs new SgList object from raw arguments

Deconstructs the SgList object into original building blocks.

Returns a reference to a idx' element of this Scatter Gather List

Iterates over &iovec stored in this SgList

Iterates over byte slices &u8

Iterates over byte slices &u8

Iterates over tuples of &iovec and associated Range describing this iovec position in the whole SgList

Iterates over tuples of &[u8] slices and associated Range describing this slice position in the whole SgList

Iterates over tuples of &mut [u8] slices and associated Range describing this slice position in the whole SgList.

Given a mask iterates over iovec that a visible after masking